import { reactive, onMounted, onUnmounted } from "vue";

export function useDynamicPageSize(defaultSize = 10, largeSize = 15) {
  // 定义分页状态
  const state = reactive({
    pageInput: {
      currentPage: 1,
      pageSize: defaultSize, // 默认分页大小
    },
  });

  // 获取页面大小
  const getPageSizeByResolution = () => {
    const screenWidth = window.innerWidth || document.documentElement.clientWidth;

    // 判断是否是 2K 分辨率（通常 2K 分辨率宽度 >= 2560）
    if (screenWidth >= 2560) {
      return largeSize; // 2K 分辨率下每页显示 largeSize 条数据
    }

    // 默认情况下显示 defaultSize 条数据
    return defaultSize;
  };

  // 更新页面大小
  const updatePageSize = () => {
    state.pageInput.pageSize = getPageSizeByResolution();
  };

  // 初始化时设置页面大小
  updatePageSize();

  // 监听窗口大小变化
  const handleResize = () => {
    updatePageSize();
  };

  onMounted(() => {
    window.addEventListener("resize", handleResize);
  });

  onUnmounted(() => {
    window.removeEventListener("resize", handleResize);
  });

  return state;
}